@@ -1,4 +1,4 @@
-/* $Id: files.c,v 1.212 2003/02/16 03:13:47 astyanax Exp $ */
+/* $Id: files.c,v 1.214 2003/04/15 01:15:09 astyanax Exp $ */
 /**************************************************************************
  *   files.c                                                              *
  *                                                                        *
@@ -495,7 +495,6 @@ int do_insertfile(int loading_file)
 		_("Command to execute"));
 	    if (ts  == -1 || answer == NULL || answer[0] == '\0') {
 		statusbar(_("Cancelled"));
-		UNSET(KEEP_CUTBUFFER);
 		display_main_list();
 		return 0;
 	    }
@@ -618,7 +617,6 @@ int do_insertfile(int loading_file)
     free(inspath);
     inspath = NULL;
 
-    UNSET(KEEP_CUTBUFFER);
     display_main_list();
     return i;
 }
@@ -1898,8 +1896,8 @@ char *real_dir_from_tilde(const char *buf)
 	for (i = 1; buf[i] != '/' && buf[i] != '\0'; i++)
 	    ;
 
-	/* Determine home directory using getpwent(), don't rely on
-	       $HOME */
+	/* Determine home directory using getpwuid() or getpwent(),
+	   don't rely on $HOME */
 	if (i == 1)
 	    userdata = getpwuid(geteuid());
 	else {
@@ -2892,8 +2890,11 @@ void load_history(void)
     if (homenv != NULL || userage != NULL) {
 	hist = fopen(nanohist, "r");
 	if (!hist) {
-            if (errno != ENOENT)
+            if (errno != ENOENT) {
+		/* Don't save history when we quit. */
+		UNSET(HISTORYLOG);
 		rcfile_error(_("Unable to open ~/.nano_history file, %s"), strerror(errno));
+	    }
 	    free(nanohist);
 	} else {
 	    buf = charalloc(1024);
