@@ -1,4 +1,4 @@
-/* $Id: global.c,v 1.106 2003/02/13 22:25:01 astyanax Exp $ */
+/* $Id: global.c,v 1.109 2003/04/19 19:34:05 astyanax Exp $ */
 /**************************************************************************
  *   global.c                                                             *
  *                                                                        *
@@ -439,16 +439,15 @@ void shortcut_init(int unjustify)
 		    IFHELP(nano_justify_msg, 0), NANO_JUSTIFY_FKEY, 0,
 		    NOVIEW, do_justify);
 
+    /* this is so we can view multiple files */
+    sc_init_one(&main_list, NANO_INSERTFILE_KEY, _("Read File"),
+		IFHELP(nano_insert_msg, 0), NANO_INSERTFILE_FKEY, 0,
 #ifdef ENABLE_MULTIBUFFER
-	/* this is so we can view multiple files */
-     sc_init_one(&main_list, NANO_INSERTFILE_KEY, _("Read File"),
-		IFHELP(nano_insert_msg, 0),
-		NANO_INSERTFILE_FKEY, 0, VIEW, do_insertfile_void);
+		VIEW
 #else
-     sc_init_one(&main_list, NANO_INSERTFILE_KEY, _("Read File"),
-		IFHELP(nano_insert_msg, 0),
-		NANO_INSERTFILE_FKEY, 0, NOVIEW, do_insertfile_void);
+		NOVIEW
 #endif
+		, do_insertfile_void);
 
     sc_init_one(&main_list, NANO_WHEREIS_KEY, _("Where Is"),
 		IFHELP(nano_whereis_msg, 0),
