@@ -1,4 +1,4 @@
-/* $Id: nano.h,v 1.99 2003/02/13 22:25:01 astyanax Exp $ */
+/* $Id: nano.h,v 1.101 2003/04/19 19:34:05 astyanax Exp $ */
 /**************************************************************************
  *   nano.h                                                               *
  *                                                                        *
@@ -35,6 +35,9 @@
 /* Define charalloc as a macro rather than duplicating code */
 #define charalloc(howmuch) (char *)nmalloc((howmuch) * sizeof(char))
 #define charealloc(ptr, howmuch) (char *)nrealloc(ptr, (howmuch) * sizeof(char))
+#ifdef BROKEN_REGEXEC
+#define regexec(preg, string, nmatch, pmatch, eflags) regexec_safe(preg, string, nmatch, pmatch, eflags)
+#endif
 
 #ifndef NANO_SMALL
   /* For the backup file copy ... */
@@ -76,13 +79,12 @@
 # endif
 #endif
 
-#if !defined(HAVE_STRCASECMP) || !defined(HAVE_STRNCASECMP)
-# ifndef HAVE_STRCASECMP
-#  define strcasecmp strcmp
-# endif
-# ifndef HAVE_STRNCASECMP
-#  define strncasecmp strncmp
-# endif
+#ifndef HAVE_STRCASECMP
+#define strcasecmp strcmp
+#endif
+
+#ifndef HAVE_STRNCASECMP
+#define strncasecmp strncmp
 #endif
 
 /* HP-UX 10 & 11 do not seem to support KEY_HOME and KEY_END */
@@ -250,6 +252,7 @@ typedef struct historyheadtype {
 #define PRESERVE		(1<<28)
 #define HISTORY_CHANGED		(1<<29)
 #define HISTORYLOG		(1<<30)
+#define JUSTIFY_MODE		(1<<31)
 
 /* Control key sequences, changing these would be very very bad */
 
