@@ -1,4 +1,4 @@
-/* $Id: utils.c,v 1.52 2003/01/26 04:45:05 astyanax Exp $ */
+/* $Id: utils.c,v 1.54 2003/04/15 01:15:09 astyanax Exp $ */
 /**************************************************************************
  *   utils.c                                                              *
  *                                                                        *
@@ -30,6 +30,18 @@
 #include "proto.h"
 #include "nano.h"
 
+#ifdef BROKEN_REGEXEC
+#undef regexec
+int regexec_safe(const regex_t *preg, const char *string, size_t nmatch,
+	regmatch_t pmatch[], int eflags)
+{
+    if (string != NULL && *string != '\0')
+	return regexec(preg, string, nmatch, pmatch, eflags);
+    return REG_NOMATCH;
+}
+#define regexec(preg, string, nmatch, pmatch, eflags) regexec_safe(preg, string, nmatch, pmatch, eflags)
+#endif
+
 int is_cntrl_char(int c)
 {
     return (-128 <= c && c < -96) || (0 <= c && c < 32) ||
@@ -62,7 +74,7 @@ void align(char **strp)
 void null_at(char **data, size_t index)
 {
     assert(data != NULL);
-    *data = (char *)nrealloc(*data, sizeof(char) * (index + 1));
+    *data = charealloc(*data, index + 1);
     (*data)[index] = '\0';
 }
 
